package
Version:
v0.0.0-...-5778a5d
Opens a new window with list of versions in this module.
Published: Jan 29, 2023
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Cloner interface {
CloneAll()
CloneProject(ID int)
CloneGroupProjects(ID int)
CloneGroupProjectsRecursive(ID int)
CloneGroups(IDs []int)
CloneGroupsRecursive(IDs int)
GetGroupList()
GetProjectsOfGroup(ID int) []interface{}
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.